package cafe;

/**
 * The customer thread that represents patrons entering the cafe. 
 */
public class CustomerThread implements Runnable 
{
    private CustomerType type;  // COFFEE or BURGER
    private CafeQueue cafe;     // the shared Cafe object
    private int door;           // which door the patron used to enter the cafe
    private int count;          // maximum number of Patrons objects per door
    
    /**
     * Constructor. 
     * @param type COFFEE or BURGER.
     * @param cafe the shared Cafe object.
     * @param door the door that the patron used to enter the cafe.
     * @param count the maximum number of patrons per door.
     */
    public CustomerThread(CustomerType type, CafeQueue cafe, int door, int count) 
    {
    	this.type = type;
    	this.cafe = cafe;
    	this.door = door;
    	this.count = count;
    }

    /**
     * The run method to execute in parallel.
     */
    @Override
    public void run()
    {
        try {
            int i = 1;
            
            while (i <= count) {
            	// Generate a new customer.
                Customer customer = new Customer(type, door, i++);
                cafe.add(customer);
                
                // Sleep to simulate an inter-arrival time.
                int maxArriveTime = customer.getType().getMaxArriveTime();
                Thread.sleep((int) (1000*maxArriveTime*Math.random()));
            }
        } 
        catch (InterruptedException ex) {}  // ignore an interruption
    }
}
