package cafe;

/**
 * The server thread that represents serving 
 * (and removing) patrons from the cafe.
 */
public class ServerThread implements Runnable 
{
    private CafeQueue cafe;  // the shared Cafe object
    private int count;  // maximum number of Patron objects to serve

    /**
     * Constructor.
     * @param cafe the shared Cafe object.
     * @param count the maximum number of patrons allowed in the cafe.
     */
    public ServerThread(CafeQueue cafe, int count) 
    {
        this.cafe = cafe;
        this.count = count;
    }

    /**
     * The run method to execute in parallel.
     */
    @Override
    public void run() 
    {
        try {
            int i = 1;
            
            while (i <= count) {
            	// Serve the customer at the head of the queue.
                Customer customer = cafe.peek();
                
                // Sleep to represent the time being served by the cafe.
                int maxServeTime = customer.getType().getMaxServeTime();
                Thread.sleep((int) (1000*maxServeTime*Math.random()));
                
                cafe.remove();
                i++;
            }
        } 
        catch (InterruptedException ex) {}  // ignore an interruption
    }
}
